/*   Cataract - Static web photo gallery generator
 *   Copyright (C) 2009 Tomas Bzatek <tbzatek@users.sourceforge.net>
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef __CGG__REPLACE_TABLE_H__
#define __CGG__REPLACE_TABLE_H__

#include <glib.h>

G_BEGIN_DECLS


typedef GHashTable ReplaceTable;


ReplaceTable * replace_table_new ();

void replace_table_free (ReplaceTable *table);


/*
 *   replace_table_add_key: add tag/value pair to replace
 *
 *      tag, value will be referenced inside
 *
 */
void replace_table_add_key (ReplaceTable *table, const gchar *tag, const gchar *value);
void replace_table_add_key_int (ReplaceTable *table, const gchar *tag, gint value);
void replace_table_add_key_printf (ReplaceTable *table, const gchar *tag, const gchar *format, ...) G_GNUC_PRINTF (3, 4);

/*
 *   replace_table_process: process buffer and replace all tags filled in the replace table
 *
 *      - reallocates source buffer
 *
 */
void replace_table_process (gchar **buffer, ReplaceTable *table);


/*
 *   adjust_tags_normal:    adjust string for normal HTML use
 *   adjust_tags_parameter: adjust string for use as tag parameter value
 *        - both funtions return newly allocated string
 */
void adjust_tags_normal (gchar **str);
void adjust_tags_parameter (gchar **str);



/*
 *   get_next_token: retrieves first token (<!-- $(TOKEN) --> or $(TOKEN)) in the string
 *      - returns newly allocated token name, caller is responsible for freeing
 *      - start and end are positions of token in the source string 's'
 *      - tag_parameter indicates where the token stands - as a tag itself ( <!-- $(TOKEN) --> )
 *        or as a parameter value of some tag ( $(TOKEN) )
 *
 */
gchar * get_next_token (const gchar *s, gchar **start, gchar **end, gboolean *tag_parameter);


G_END_DECLS

#endif /* __CGG__REPLACE_TABLE_H__ */
